<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>



-------------------------------------------------------------------------------

## 📚简介

poimage 是python自动化办公之图片操作的第三方库。

来自于开源项目：python-office，[📘官网：https://www.python-office.com/](https://www.python-office.com/)。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ poimage -U
```

-------------------------------------------------------------------------------

## 📝功能

已有功能的说明如下：

| 序号 | 方法名            | 功能            | 视频                                                   | 文档                                                      | 演示代码                                                                                                                                                                        |
|----|----------------|---------------|------------------------------------------------------|---------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1  | add_watermark  | 👩给图片 加 水印    | 👩 [播放](https://www.bilibili.com/video/BV1jT411T7n9) | 待编辑                                                     | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/poimage/%E5%9B%BE%E7%89%87%E5%8A%A0%E6%B0%B4%E5%8D%B0.py)                                               |
| 2  | down4img       | 下载图片          | [播放](https://www.bilibili.com/video/BV1i8411s7Mq)    | [查看](https://mp.weixin.qq.com/s/H9NVBxwo_po8WsqsIRJ7YQ) | [打开](https://github.com/CoderWanFeng/python-office/tree/master/demo/poimage/下载图片.py)                                                                                        |
| 3  | del_watermark  | 图片去水印         | 待录制                                                  | [查看](https://mp.weixin.qq.com/s/6RS0oo6dNa3mov_5XwNurg) | [打开](https://github.com/CoderWanFeng/python-office/tree/master/demo/poimage/图片去水印.py)                                                                                       |
| 4  | txt2wordcloud  | 根据文档内容，生成词云图片 | [播放](https://www.bilibili.com/video/BV1Me4y1h7Ku)    | 待编辑                                                     | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/pydatav/%E6%95%B0%E6%8D%AE%E5%8F%AF%E8%A7%86%E5%8C%96-%E6%96%87%E7%AB%A0%E8%BD%AC%E5%9B%BE%E4%BA%91.py) |
| 5  | compress_image | 压缩图片          | 待录制                                                  | 待编辑                                                     | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/pydatav/%E6%95%B0%E6%8D%AE%E5%8F%AF%E8%A7%86%E5%8C%96-%E6%96%87%E7%AB%A0%E8%BD%AC%E5%9B%BE%E4%BA%91.py) |
| 6  | image2gif      | 图片转Gif        | 待录制                                                  | 待编辑                                                     | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/pydatav/%E6%95%B0%E6%8D%AE%E5%8F%AF%E8%A7%86%E5%8C%96-%E6%96%87%E7%AB%A0%E8%BD%AC%E5%9B%BE%E4%BA%91.py) |
| 7  | img2Cartoon | 生成动漫头像    | 待录制                                               | 待编辑 | 待开发  |

## 🏗️添砖加瓦

本项目欢迎任何人参与开发，如果是小白，可以看一下开发教程👉[如何参与开源项目？0基础入门：怎么打开GitHub？什么是issue？什么是PR？](https://www.bilibili.com/video/BV1EP411d7Np/?spm_id_from=333.999.0.0)

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和该项目本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/poimage/issues)
- [gitee issue](https://gitee.com/CoderWanFeng/poimage/issues)
### 🧬贡献代码的步骤

1. 在Gitee或者Github上fork项目到自己的repo
2. 把fork过去的项目也就是你的项目clone到你的本地
3. 修改代码
4. commit后push到自己的库
5. 登录Gitee或Github在你首页可以看到一个 pull request 按钮，点击它，填写一些说明信息，然后提交到master分支即可。
6. 等待程序员晚枫合并，＋微信说一声更好👉[CoderWanFeng](http://python4office.cn/wechat-qrcode/)

-------------------------------------------------------------------------------

## 📌联系作者

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>

## 读者福利

几个没有套路的福利，每天都可以领一次~

<p align="center" id='福利合集-banner'>
    <a target="_blank" href='http://python4office.cn/sideline-pro-list/'>
    <img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/fuli.jpg" width="100%"/>
    </a>   
</p>